[![pipeline status](https://gitlab.com/meltano/meltano/badges/master/pipeline.svg)](https://gitlab.com/meltano/meltano/commits/master)

# Meltano: open source ELT

[Meltano](https://meltano.com) is an open source platform for
building, running & orchestrating ELT pipelines made up of
[Singer](https://www.singer.io/) taps and targets and [dbt](https://www.getdbt.com)
models, that you can [run locally](https://meltano.com/docs/installation.html) or
[easily deploy in production](https://meltano.com/docs/production.html).

## Documentation

You can find our documentation at [https://www.meltano.com/docs/](https://www.meltano.com/docs/).

## Contributing to Meltano

We welcome contributions and improvements, please see the [contribution guidelines](https://meltano.com/docs/contributor-guide.html)

## Responsible Disclosure Policy

Please refer to the [responsible disclosure policy](https://meltano.com/docs/responsible-disclosure.html) on our website.

## License

This code is distributed under the MIT license, see the [LICENSE](LICENSE) file.
